@@ -1,4 +1,4 @@
-"binGrid" <-
+`binGrid` <-
 function( val, coord1, coord2, nGrid = 65){
    size <- nGrid
    grid <- matrix(NA, size,size)  
