@@ -46,7 +46,8 @@ function(ensembleData, trainingDays, date = NULL)
 
  DATEShh <- getHH(DATES)
 
- if (length(DATEShh) != 1) stop("forecast hour in data should be unique")
+ if (length(DATEShh) != 1) 
+    warning("valid dates do not have a unique forcast hour")
 
  if (!(lD <- unique(sapply(DATES,nchar)))) 
    stop("all dates in data should have same character length")
@@ -58,9 +59,10 @@ function(ensembleData, trainingDays, date = NULL)
 
     datesHH <- getHH(dates)
 
-    if (length(datesHH) != 1) stop("forecast hour in dates should be unique")
-   
-    if (datesHH != DATEShh) stop("specified dates incompatible with data")
+    if (length(datesHH) != 1) 
+       warning("dates do not have a unique forcast hour")
+
+    if (any(datesHH != DATEShh)) stop("specified dates incompatible with data")
 
     if (!(ld <- unique(sapply(dates,nchar)))) 
       stop("all specified dates should have same character length")
